import { ReactElement } from 'react';
export type typographyTypes = 'headings' | 'body' | 'label';
export type typographyVariants = 'h1' | 'h1Light' | 'h2' | 'h3' | 'h4' | 'primary' | 'secondary' | 'tertiary';
export type borderRadiusType = 'none' | 'tiny' | 'small' | 'medium' | 'elipse';
export type SpacingType = {
    borderRadius: Record<borderRadiusType, string>;
    [key: string]: Record<string, string>;
};
export type TypographyProps = {
    fontSize: string;
    lineHeight: string;
    fontWeight: number;
};
export type EffectType = {
    shadow: Record<'lvl0' | 'lvl1' | 'lvl2' | 'lvl3' | 'lvl4' | 'lvl5', unknown>;
};
export type contentType = {
    accent: string;
    base: string;
    subtle: string;
    weak: string;
    baseInverse: string;
    subtleInverse: string;
    weakInverse: string;
    danger: string;
    warning: string;
    success: string;
};
export type contentStateType = {
    accent: statesType;
    base: statesType;
    subtle: statesType;
    weak: statesType;
    baseInverse: statesType;
    subtleInverse: statesType;
    weakInverse: statesType;
    danger: statesType;
    warning: statesType;
    success: statesType;
};
export type statesType = {
    hover: string;
    active: string;
    disable: string;
};
export type backgroundType = {
    accent: string;
    accentLight: string;
    base: string;
    subtle: string;
    weak: string;
    dark: string;
    darkLight: string;
    transaction: string;
    danger: string;
    dangerLight: string;
    warning: string;
    warningLight: string;
    success: string;
    successLight: string;
};
export type backgroundStateType = {
    accent: statesType;
    accentLight: statesType;
    base: statesType;
    dark: statesType;
    darkLight: statesType;
    transaction: statesType;
};
export type textIconPropsType = {
    default: string;
    hover: string;
    disabled: string;
};
export type actionPropsType = textIconPropsType & {
    active: string;
};
export type actionType = {
    background: {
        primary: {
            base: actionPropsType;
            subtle: actionPropsType;
        };
        secondary: {
            base: actionPropsType;
            subtle: actionPropsType;
        };
        tertiary: {
            base: actionPropsType;
            subtle: actionPropsType;
        };
        danger: actionPropsType;
        success: actionPropsType;
        warning: actionPropsType;
    };
    textIcon: {
        primary: textIconPropsType & {
            inverse: textIconPropsType;
        };
        secondary: textIconPropsType;
        tertiary: textIconPropsType;
        danger: textIconPropsType;
        success: textIconPropsType;
        warning: textIconPropsType;
        input: textIconPropsType;
    };
};
export type borderType = {
    base: string;
    subtle: string;
    weak: string;
    dark: string;
    darkLight: string;
    accent: string;
    focus: string;
    danger: string;
    warning: string;
    success: string;
};
export type borderStateType = {
    dark: statesType;
    darkLight: statesType;
    accent: statesType;
    focus: statesType;
    danger: statesType;
    warning: statesType;
    success: statesType;
};
export type ColorsType = {
    content: contentType;
    contentState: contentStateType;
    background: backgroundType;
    backgroundState: backgroundStateType;
    border: borderType;
    borderState: borderStateType;
};
export type TypographyType = {
    desktop: typographyPropsType;
    mobile: typographyPropsType;
};
export type typographyPropsType = {
    headings: headingsType;
    body: bodyType;
    label: bodyType;
    input: inputType;
    button: bodyType;
};
export type fontPropsType = {
    fontWeight: string;
    lineHeight: string;
    fontSize: string;
    letterSpacing: string;
    paragraphSpacing?: string;
    textDecoration?: string;
    textCase?: string;
};
export type headingsType = {
    h1: fontPropsType;
    h1Light: fontPropsType;
    h2: fontPropsType;
    h3: fontPropsType;
    h4: fontPropsType;
};
export type inputType = {
    primary: fontPropsType;
    secondary: fontPropsType;
};
export type bodyType = inputType & {
    tertiary: fontPropsType;
};
export type ThemeType = {
    colors: ColorsType;
    spacing: SpacingType;
    typography: TypographyType;
    effects: EffectType;
    components: Record<string, any>;
    tokens?: Record<string, any>;
};
export type BolttechThemeProviderPropsType = {
    children?: ReactElement | ReactElement[];
    theme: ThemeType;
};
