import { PropsWithChildren } from 'react';
/**
 * An array representing a range of sizes from 0 to 100.
 */
declare const sizeRange: any[];
/**
 * A type alias for the type of the sizeRange array.
 */
type TSizes = typeof sizeRange;
/**
 * An object representing different size ranges for different screen sizes.
 * @typedef {Object} TSizesProps
 * @property {TSizes} xs - The size range for extra small screens.
 * @property {TSizes} sm - The size range for small screens.
 * @property {TSizes} md - The size range for medium screens.
 * @property {TSizes} lg - The size range for large screens.
 */
export type TSizesProps = {
    xs: TSizes;
    sm: TSizes;
    md: TSizes;
    lg: TSizes;
};
/**
 * Props for a container component.
 * @interface IContainerProps
 * @extends PropsWithChildren
 * @property {string} [className] - The CSS class name for the container.
 * @property {boolean} [removeGridGap] - Whether to remove the grid gap between items in the container.
 * @property {boolean} [removeGridPadding] - Whether to remove the grid padding of the container.
 * @property {TSizesProps} [sizes] - The size ranges for different screen sizes.
 * @property {(event?: React.MouseEvent<HTMLDivElement>) => void} [onClick] - The onClick event handler for the Box.
 */
export interface IContainerProps extends PropsWithChildren {
    className?: string | string[];
    removeGridGap?: boolean;
    removeGridPadding?: boolean;
    sizes?: TSizesProps;
    onClick?: (event?: React.MouseEvent<HTMLDivElement>) => void;
}
export {};
